# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1626, 982)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(0, 200))
        Dialog.setSizeGripEnabled(False)
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.tabWidget = QtWidgets.QTabWidget(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(0, 400))
        self.tabWidget.setObjectName("tabWidget")
        self.tabImages = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabImages.sizePolicy().hasHeightForWidth())
        self.tabImages.setSizePolicy(sizePolicy)
        self.tabImages.setObjectName("tabImages")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tabImages)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.gridLayout_5 = QtWidgets.QGridLayout()
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.comboBoxSnrweight = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxSnrweight.setObjectName("comboBoxSnrweight")
        self.comboBoxSnrweight.addItem("")
        self.comboBoxSnrweight.addItem("")
        self.comboBoxSnrweight.addItem("")
        self.horizontalLayout_10.addWidget(self.comboBoxSnrweight)
        self.doubleSpinBoxSnrweight = QtWidgets.QDoubleSpinBox(self.tabImages)
        self.doubleSpinBoxSnrweight.setObjectName("doubleSpinBoxSnrweight")
        self.horizontalLayout_10.addWidget(self.doubleSpinBoxSnrweight)
        self.gridLayout_5.addLayout(self.horizontalLayout_10, 1, 9, 1, 1)
        self.dateEditStartDate = QtWidgets.QDateTimeEdit(self.tabImages)
        self.dateEditStartDate.setCalendarPopup(True)
        self.dateEditStartDate.setObjectName("dateEditStartDate")
        self.gridLayout_5.addWidget(self.dateEditStartDate, 1, 11, 1, 1)
        self.labelExposure = QtWidgets.QLabel(self.tabImages)
        self.labelExposure.setObjectName("labelExposure")
        self.gridLayout_5.addWidget(self.labelExposure, 3, 2, 1, 1)
        self.labelSnrweight = QtWidgets.QLabel(self.tabImages)
        self.labelSnrweight.setObjectName("labelSnrweight")
        self.gridLayout_5.addWidget(self.labelSnrweight, 1, 8, 1, 1)
        self.dateEditEndDate = QtWidgets.QDateTimeEdit(self.tabImages)
        self.dateEditEndDate.setCalendarPopup(True)
        self.dateEditEndDate.setObjectName("dateEditEndDate")
        self.gridLayout_5.addWidget(self.dateEditEndDate, 3, 11, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.comboBoxExposure = QtWidgets.QComboBox(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBoxExposure.sizePolicy().hasHeightForWidth())
        self.comboBoxExposure.setSizePolicy(sizePolicy)
        self.comboBoxExposure.setObjectName("comboBoxExposure")
        self.comboBoxExposure.addItem("")
        self.comboBoxExposure.addItem("")
        self.comboBoxExposure.addItem("")
        self.horizontalLayout_3.addWidget(self.comboBoxExposure)
        self.lineEditExposure = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditExposure.sizePolicy().hasHeightForWidth())
        self.lineEditExposure.setSizePolicy(sizePolicy)
        self.lineEditExposure.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditExposure.setObjectName("lineEditExposure")
        self.horizontalLayout_3.addWidget(self.lineEditExposure)
        self.gridLayout_5.addLayout(self.horizontalLayout_3, 3, 3, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem, 3, 15, 1, 1)
        self.labelEccentricity = QtWidgets.QLabel(self.tabImages)
        self.labelEccentricity.setObjectName("labelEccentricity")
        self.gridLayout_5.addWidget(self.labelEccentricity, 3, 6, 1, 1)
        self.lineEditTarget = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditTarget.sizePolicy().hasHeightForWidth())
        self.lineEditTarget.setSizePolicy(sizePolicy)
        self.lineEditTarget.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditTarget.setObjectName("lineEditTarget")
        self.gridLayout_5.addWidget(self.lineEditTarget, 1, 1, 1, 1)
        self.labelFwhm = QtWidgets.QLabel(self.tabImages)
        self.labelFwhm.setObjectName("labelFwhm")
        self.gridLayout_5.addWidget(self.labelFwhm, 1, 6, 1, 1)
        self.pushButtonDeleteRow = QtWidgets.QPushButton(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonDeleteRow.sizePolicy().hasHeightForWidth())
        self.pushButtonDeleteRow.setSizePolicy(sizePolicy)
        self.pushButtonDeleteRow.setObjectName("pushButtonDeleteRow")
        self.gridLayout_5.addWidget(self.pushButtonDeleteRow, 1, 13, 1, 1)
        self.labelStartDate = QtWidgets.QLabel(self.tabImages)
        self.labelStartDate.setObjectName("labelStartDate")
        self.gridLayout_5.addWidget(self.labelStartDate, 1, 10, 1, 1)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.comboBoxNoise = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxNoise.setObjectName("comboBoxNoise")
        self.comboBoxNoise.addItem("")
        self.comboBoxNoise.addItem("")
        self.comboBoxNoise.addItem("")
        self.horizontalLayout_11.addWidget(self.comboBoxNoise)
        self.doubleSpinBoxNoise = QtWidgets.QDoubleSpinBox(self.tabImages)
        self.doubleSpinBoxNoise.setObjectName("doubleSpinBoxNoise")
        self.horizontalLayout_11.addWidget(self.doubleSpinBoxNoise)
        self.gridLayout_5.addLayout(self.horizontalLayout_11, 3, 9, 1, 1)
        self.lineEditFrame = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditFrame.sizePolicy().hasHeightForWidth())
        self.lineEditFrame.setSizePolicy(sizePolicy)
        self.lineEditFrame.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditFrame.setObjectName("lineEditFrame")
        self.gridLayout_5.addWidget(self.lineEditFrame, 1, 3, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(13, 24, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem1, 1, 15, 1, 1)
        self.lineEditFilter = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditFilter.sizePolicy().hasHeightForWidth())
        self.lineEditFilter.setSizePolicy(sizePolicy)
        self.lineEditFilter.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditFilter.setObjectName("lineEditFilter")
        self.gridLayout_5.addWidget(self.lineEditFilter, 3, 1, 1, 1)
        self.pushButtonGraph = QtWidgets.QPushButton(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonGraph.sizePolicy().hasHeightForWidth())
        self.pushButtonGraph.setSizePolicy(sizePolicy)
        self.pushButtonGraph.setObjectName("pushButtonGraph")
        self.gridLayout_5.addWidget(self.pushButtonGraph, 3, 12, 1, 1)
        self.labelNoise = QtWidgets.QLabel(self.tabImages)
        self.labelNoise.setObjectName("labelNoise")
        self.gridLayout_5.addWidget(self.labelNoise, 3, 8, 1, 1)
        self.pushButtonLastNight = QtWidgets.QPushButton(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonLastNight.sizePolicy().hasHeightForWidth())
        self.pushButtonLastNight.setSizePolicy(sizePolicy)
        self.pushButtonLastNight.setObjectName("pushButtonLastNight")
        self.gridLayout_5.addWidget(self.pushButtonLastNight, 1, 12, 1, 1)
        self.labelFrame = QtWidgets.QLabel(self.tabImages)
        self.labelFrame.setObjectName("labelFrame")
        self.gridLayout_5.addWidget(self.labelFrame, 1, 2, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.comboBoxAz = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxAz.setObjectName("comboBoxAz")
        self.comboBoxAz.addItem("")
        self.comboBoxAz.addItem("")
        self.comboBoxAz.addItem("")
        self.horizontalLayout_4.addWidget(self.comboBoxAz)
        self.lineEditAz = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAz.sizePolicy().hasHeightForWidth())
        self.lineEditAz.setSizePolicy(sizePolicy)
        self.lineEditAz.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditAz.setObjectName("lineEditAz")
        self.horizontalLayout_4.addWidget(self.lineEditAz)
        self.gridLayout_5.addLayout(self.horizontalLayout_4, 1, 5, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.comboBoxEccentricity = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxEccentricity.setObjectName("comboBoxEccentricity")
        self.comboBoxEccentricity.addItem("")
        self.comboBoxEccentricity.addItem("")
        self.comboBoxEccentricity.addItem("")
        self.horizontalLayout_9.addWidget(self.comboBoxEccentricity)
        self.doubleSpinBoxEccentricity = QtWidgets.QDoubleSpinBox(self.tabImages)
        self.doubleSpinBoxEccentricity.setObjectName("doubleSpinBoxEccentricity")
        self.horizontalLayout_9.addWidget(self.doubleSpinBoxEccentricity)
        self.gridLayout_5.addLayout(self.horizontalLayout_9, 3, 7, 1, 1)
        self.labelFilter = QtWidgets.QLabel(self.tabImages)
        self.labelFilter.setObjectName("labelFilter")
        self.gridLayout_5.addWidget(self.labelFilter, 3, 0, 1, 1)
        self.labelTarget = QtWidgets.QLabel(self.tabImages)
        self.labelTarget.setObjectName("labelTarget")
        self.gridLayout_5.addWidget(self.labelTarget, 1, 0, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.comboBoxAlt = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxAlt.setObjectName("comboBoxAlt")
        self.comboBoxAlt.addItem("")
        self.comboBoxAlt.addItem("")
        self.comboBoxAlt.addItem("")
        self.horizontalLayout_7.addWidget(self.comboBoxAlt)
        self.lineEditAlt = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAlt.sizePolicy().hasHeightForWidth())
        self.lineEditAlt.setSizePolicy(sizePolicy)
        self.lineEditAlt.setMinimumSize(QtCore.QSize(40, 0))
        self.lineEditAlt.setObjectName("lineEditAlt")
        self.horizontalLayout_7.addWidget(self.lineEditAlt)
        self.gridLayout_5.addLayout(self.horizontalLayout_7, 3, 5, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.comboBoxFwhm = QtWidgets.QComboBox(self.tabImages)
        self.comboBoxFwhm.setObjectName("comboBoxFwhm")
        self.comboBoxFwhm.addItem("")
        self.comboBoxFwhm.addItem("")
        self.comboBoxFwhm.addItem("")
        self.horizontalLayout_8.addWidget(self.comboBoxFwhm)
        self.doubleSpinBoxFwhm = QtWidgets.QDoubleSpinBox(self.tabImages)
        self.doubleSpinBoxFwhm.setObjectName("doubleSpinBoxFwhm")
        self.horizontalLayout_8.addWidget(self.doubleSpinBoxFwhm)
        self.gridLayout_5.addLayout(self.horizontalLayout_8, 1, 7, 1, 1)
        self.labelAz = QtWidgets.QLabel(self.tabImages)
        self.labelAz.setObjectName("labelAz")
        self.gridLayout_5.addWidget(self.labelAz, 1, 4, 1, 1)
        self.labelAlt = QtWidgets.QLabel(self.tabImages)
        self.labelAlt.setObjectName("labelAlt")
        self.gridLayout_5.addWidget(self.labelAlt, 3, 4, 1, 1)
        self.labelEndDate = QtWidgets.QLabel(self.tabImages)
        self.labelEndDate.setObjectName("labelEndDate")
        self.gridLayout_5.addWidget(self.labelEndDate, 3, 10, 1, 1)
        self.pushButtonDashboard = QtWidgets.QPushButton(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonDashboard.sizePolicy().hasHeightForWidth())
        self.pushButtonDashboard.setSizePolicy(sizePolicy)
        self.pushButtonDashboard.setObjectName("pushButtonDashboard")
        self.gridLayout_5.addWidget(self.pushButtonDashboard, 3, 13, 1, 1)
        self.pushButtonExportCsv = QtWidgets.QPushButton(self.tabImages)
        self.pushButtonExportCsv.setObjectName("pushButtonExportCsv")
        self.gridLayout_5.addWidget(self.pushButtonExportCsv, 1, 14, 1, 1)
        self.verticalLayout_9.addLayout(self.gridLayout_5)
        self.tableViewImages = QtWidgets.QTableView(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableViewImages.sizePolicy().hasHeightForWidth())
        self.tableViewImages.setSizePolicy(sizePolicy)
        self.tableViewImages.setMinimumSize(QtCore.QSize(0, 200))
        self.tableViewImages.setCornerButtonEnabled(True)
        self.tableViewImages.setObjectName("tableViewImages")
        self.verticalLayout_9.addWidget(self.tableViewImages)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.lineEditMeanNoise = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditMeanNoise.sizePolicy().hasHeightForWidth())
        self.lineEditMeanNoise.setSizePolicy(sizePolicy)
        self.lineEditMeanNoise.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditMeanNoise.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditMeanNoise.setToolTip("")
        self.lineEditMeanNoise.setToolTipDuration(1)
        self.lineEditMeanNoise.setReadOnly(True)
        self.lineEditMeanNoise.setObjectName("lineEditMeanNoise")
        self.gridLayout_2.addWidget(self.lineEditMeanNoise, 0, 16, 1, 1)
        self.labelMeanEccentricity = QtWidgets.QLabel(self.tabImages)
        self.labelMeanEccentricity.setObjectName("labelMeanEccentricity")
        self.gridLayout_2.addWidget(self.labelMeanEccentricity, 0, 9, 1, 1)
        self.labelMeanNoise = QtWidgets.QLabel(self.tabImages)
        self.labelMeanNoise.setObjectName("labelMeanNoise")
        self.gridLayout_2.addWidget(self.labelMeanNoise, 0, 15, 1, 1)
        self.lineEditMeanFwhm = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditMeanFwhm.sizePolicy().hasHeightForWidth())
        self.lineEditMeanFwhm.setSizePolicy(sizePolicy)
        self.lineEditMeanFwhm.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditMeanFwhm.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditMeanFwhm.setToolTip("")
        self.lineEditMeanFwhm.setReadOnly(True)
        self.lineEditMeanFwhm.setObjectName("lineEditMeanFwhm")
        self.gridLayout_2.addWidget(self.lineEditMeanFwhm, 0, 7, 1, 1)
        self.labelCurrentDb = QtWidgets.QLabel(self.tabImages)
        self.labelCurrentDb.setObjectName("labelCurrentDb")
        self.gridLayout_2.addWidget(self.labelCurrentDb, 0, 18, 1, 1)
        self.lineEditSigmaSnr = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSigmaSnr.sizePolicy().hasHeightForWidth())
        self.lineEditSigmaSnr.setSizePolicy(sizePolicy)
        self.lineEditSigmaSnr.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditSigmaSnr.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditSigmaSnr.setToolTip("")
        self.lineEditSigmaSnr.setToolTipDuration(1)
        self.lineEditSigmaSnr.setReadOnly(True)
        self.lineEditSigmaSnr.setObjectName("lineEditSigmaSnr")
        self.gridLayout_2.addWidget(self.lineEditSigmaSnr, 0, 14, 1, 1)
        self.labelMeanAlt = QtWidgets.QLabel(self.tabImages)
        self.labelMeanAlt.setObjectName("labelMeanAlt")
        self.gridLayout_2.addWidget(self.labelMeanAlt, 0, 3, 1, 1)
        self.lineEditSigmaNoise = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSigmaNoise.sizePolicy().hasHeightForWidth())
        self.lineEditSigmaNoise.setSizePolicy(sizePolicy)
        self.lineEditSigmaNoise.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditSigmaNoise.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditSigmaNoise.setToolTip("")
        self.lineEditSigmaNoise.setReadOnly(True)
        self.lineEditSigmaNoise.setObjectName("lineEditSigmaNoise")
        self.gridLayout_2.addWidget(self.lineEditSigmaNoise, 0, 17, 1, 1)
        self.labelTotExposure = QtWidgets.QLabel(self.tabImages)
        self.labelTotExposure.setObjectName("labelTotExposure")
        self.gridLayout_2.addWidget(self.labelTotExposure, 0, 0, 1, 1)
        self.lineEditTotExposure = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditTotExposure.sizePolicy().hasHeightForWidth())
        self.lineEditTotExposure.setSizePolicy(sizePolicy)
        self.lineEditTotExposure.setMinimumSize(QtCore.QSize(50, 26))
        self.lineEditTotExposure.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditTotExposure.setToolTip("")
        self.lineEditTotExposure.setReadOnly(True)
        self.lineEditTotExposure.setObjectName("lineEditTotExposure")
        self.gridLayout_2.addWidget(self.lineEditTotExposure, 0, 2, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem2, 0, 19, 1, 1)
        self.lineEditMeanSnr = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditMeanSnr.sizePolicy().hasHeightForWidth())
        self.lineEditMeanSnr.setSizePolicy(sizePolicy)
        self.lineEditMeanSnr.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditMeanSnr.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditMeanSnr.setToolTip("")
        self.lineEditMeanSnr.setReadOnly(True)
        self.lineEditMeanSnr.setObjectName("lineEditMeanSnr")
        self.gridLayout_2.addWidget(self.lineEditMeanSnr, 0, 13, 1, 1)
        self.lineEditMeanEccentricity = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditMeanEccentricity.sizePolicy().hasHeightForWidth())
        self.lineEditMeanEccentricity.setSizePolicy(sizePolicy)
        self.lineEditMeanEccentricity.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditMeanEccentricity.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditMeanEccentricity.setToolTip("")
        self.lineEditMeanEccentricity.setReadOnly(True)
        self.lineEditMeanEccentricity.setObjectName("lineEditMeanEccentricity")
        self.gridLayout_2.addWidget(self.lineEditMeanEccentricity, 0, 10, 1, 1)
        self.lineEditSigmaAlt = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSigmaAlt.sizePolicy().hasHeightForWidth())
        self.lineEditSigmaAlt.setSizePolicy(sizePolicy)
        self.lineEditSigmaAlt.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditSigmaAlt.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditSigmaAlt.setToolTip("")
        self.lineEditSigmaAlt.setReadOnly(True)
        self.lineEditSigmaAlt.setObjectName("lineEditSigmaAlt")
        self.gridLayout_2.addWidget(self.lineEditSigmaAlt, 0, 5, 1, 1)
        self.labelMeanFwhm = QtWidgets.QLabel(self.tabImages)
        self.labelMeanFwhm.setStyleSheet("")
        self.labelMeanFwhm.setObjectName("labelMeanFwhm")
        self.gridLayout_2.addWidget(self.labelMeanFwhm, 0, 6, 1, 1)
        self.lineEditTotImages = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditTotImages.sizePolicy().hasHeightForWidth())
        self.lineEditTotImages.setSizePolicy(sizePolicy)
        self.lineEditTotImages.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditTotImages.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditTotImages.setToolTip("")
        self.lineEditTotImages.setReadOnly(True)
        self.lineEditTotImages.setObjectName("lineEditTotImages")
        self.gridLayout_2.addWidget(self.lineEditTotImages, 0, 1, 1, 1)
        self.lineEditMeanAlt = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditMeanAlt.sizePolicy().hasHeightForWidth())
        self.lineEditMeanAlt.setSizePolicy(sizePolicy)
        self.lineEditMeanAlt.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditMeanAlt.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditMeanAlt.setToolTip("")
        self.lineEditMeanAlt.setReadOnly(True)
        self.lineEditMeanAlt.setObjectName("lineEditMeanAlt")
        self.gridLayout_2.addWidget(self.lineEditMeanAlt, 0, 4, 1, 1)
        self.labelMeanSnr = QtWidgets.QLabel(self.tabImages)
        self.labelMeanSnr.setObjectName("labelMeanSnr")
        self.gridLayout_2.addWidget(self.labelMeanSnr, 0, 12, 1, 1)
        self.lineEditSigmaEccentricity = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSigmaEccentricity.sizePolicy().hasHeightForWidth())
        self.lineEditSigmaEccentricity.setSizePolicy(sizePolicy)
        self.lineEditSigmaEccentricity.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditSigmaEccentricity.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditSigmaEccentricity.setToolTip("")
        self.lineEditSigmaEccentricity.setReadOnly(True)
        self.lineEditSigmaEccentricity.setObjectName("lineEditSigmaEccentricity")
        self.gridLayout_2.addWidget(self.lineEditSigmaEccentricity, 0, 11, 1, 1)
        self.lineEditSigmaFwhm = QtWidgets.QLineEdit(self.tabImages)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSigmaFwhm.sizePolicy().hasHeightForWidth())
        self.lineEditSigmaFwhm.setSizePolicy(sizePolicy)
        self.lineEditSigmaFwhm.setMinimumSize(QtCore.QSize(40, 26))
        self.lineEditSigmaFwhm.setMaximumSize(QtCore.QSize(60, 26))
        self.lineEditSigmaFwhm.setToolTip("")
        self.lineEditSigmaFwhm.setReadOnly(True)
        self.lineEditSigmaFwhm.setObjectName("lineEditSigmaFwhm")
        self.gridLayout_2.addWidget(self.lineEditSigmaFwhm, 0, 8, 1, 1)
        self.verticalLayout_9.addLayout(self.gridLayout_2)
        self.verticalLayout_5.addLayout(self.verticalLayout_9)
        self.tabWidget.addTab(self.tabImages, "")
        self.tabImportFits = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabImportFits.sizePolicy().hasHeightForWidth())
        self.tabImportFits.setSizePolicy(sizePolicy)
        self.tabImportFits.setToolTipDuration(-4)
        self.tabImportFits.setObjectName("tabImportFits")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tabImportFits)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBoxFitsImport = QtWidgets.QGroupBox(self.tabImportFits)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxFitsImport.sizePolicy().hasHeightForWidth())
        self.groupBoxFitsImport.setSizePolicy(sizePolicy)
        self.groupBoxFitsImport.setMinimumSize(QtCore.QSize(0, 100))
        self.groupBoxFitsImport.setObjectName("groupBoxFitsImport")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBoxFitsImport)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.pushButtonLoadFits = QtWidgets.QPushButton(self.groupBoxFitsImport)
        self.pushButtonLoadFits.setObjectName("pushButtonLoadFits")
        self.gridLayout_3.addWidget(self.pushButtonLoadFits, 0, 2, 1, 1)
        self.pushButtonSaveFits = QtWidgets.QPushButton(self.groupBoxFitsImport)
        icon = QtGui.QIcon.fromTheme("save")
        self.pushButtonSaveFits.setIcon(icon)
        self.pushButtonSaveFits.setObjectName("pushButtonSaveFits")
        self.gridLayout_3.addWidget(self.pushButtonSaveFits, 0, 3, 1, 1)
        self.pushButtonDeleteFitsRow = QtWidgets.QPushButton(self.groupBoxFitsImport)
        self.pushButtonDeleteFitsRow.setObjectName("pushButtonDeleteFitsRow")
        self.gridLayout_3.addWidget(self.pushButtonDeleteFitsRow, 0, 4, 1, 1)
        self.lineEditFitsDir = QtWidgets.QLineEdit(self.groupBoxFitsImport)
        self.lineEditFitsDir.setMaximumSize(QtCore.QSize(200, 16777215))
        self.lineEditFitsDir.setObjectName("lineEditFitsDir")
        self.gridLayout_3.addWidget(self.lineEditFitsDir, 0, 0, 1, 1)
        self.pushButtonChooseFitsDir = QtWidgets.QPushButton(self.groupBoxFitsImport)
        self.pushButtonChooseFitsDir.setObjectName("pushButtonChooseFitsDir")
        self.gridLayout_3.addWidget(self.pushButtonChooseFitsDir, 0, 1, 1, 1)
        self.lineEditOverrideTarget = QtWidgets.QLineEdit(self.groupBoxFitsImport)
        self.lineEditOverrideTarget.setMaximumSize(QtCore.QSize(200, 16777215))
        self.lineEditOverrideTarget.setObjectName("lineEditOverrideTarget")
        self.gridLayout_3.addWidget(self.lineEditOverrideTarget, 1, 0, 1, 1)
        self.labelOverrideTarget = QtWidgets.QLabel(self.groupBoxFitsImport)
        self.labelOverrideTarget.setObjectName("labelOverrideTarget")
        self.gridLayout_3.addWidget(self.labelOverrideTarget, 1, 1, 1, 3)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem3, 0, 5, 1, 1)
        self.verticalLayout_3.addWidget(self.groupBoxFitsImport)
        self.tableViewImportFits = QtWidgets.QTableView(self.tabImportFits)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableViewImportFits.sizePolicy().hasHeightForWidth())
        self.tableViewImportFits.setSizePolicy(sizePolicy)
        self.tableViewImportFits.setMinimumSize(QtCore.QSize(0, 200))
        self.tableViewImportFits.setObjectName("tableViewImportFits")
        self.verticalLayout_3.addWidget(self.tableViewImportFits)
        self.plainTextEditLogFits = QtWidgets.QPlainTextEdit(self.tabImportFits)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plainTextEditLogFits.sizePolicy().hasHeightForWidth())
        self.plainTextEditLogFits.setSizePolicy(sizePolicy)
        self.plainTextEditLogFits.setMinimumSize(QtCore.QSize(0, 40))
        self.plainTextEditLogFits.setReadOnly(True)
        self.plainTextEditLogFits.setObjectName("plainTextEditLogFits")
        self.verticalLayout_3.addWidget(self.plainTextEditLogFits)
        self.tabWidget.addTab(self.tabImportFits, "")
        self.tabImportCsv = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabImportCsv.sizePolicy().hasHeightForWidth())
        self.tabImportCsv.setSizePolicy(sizePolicy)
        self.tabImportCsv.setObjectName("tabImportCsv")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tabImportCsv)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.groupBoxCsv = QtWidgets.QGroupBox(self.tabImportCsv)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxCsv.sizePolicy().hasHeightForWidth())
        self.groupBoxCsv.setSizePolicy(sizePolicy)
        self.groupBoxCsv.setMinimumSize(QtCore.QSize(0, 100))
        self.groupBoxCsv.setObjectName("groupBoxCsv")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBoxCsv)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.lineEditPathConversionFrom = QtWidgets.QLineEdit(self.groupBoxCsv)
        self.lineEditPathConversionFrom.setObjectName("lineEditPathConversionFrom")
        self.gridLayout_4.addWidget(self.lineEditPathConversionFrom, 0, 6, 1, 1)
        self.pushButtonChooseCsv = QtWidgets.QPushButton(self.groupBoxCsv)
        self.pushButtonChooseCsv.setObjectName("pushButtonChooseCsv")
        self.gridLayout_4.addWidget(self.pushButtonChooseCsv, 0, 1, 1, 1)
        self.pushButtonSaveCsv = QtWidgets.QPushButton(self.groupBoxCsv)
        self.pushButtonSaveCsv.setObjectName("pushButtonSaveCsv")
        self.gridLayout_4.addWidget(self.pushButtonSaveCsv, 0, 2, 1, 1)
        self.pushButtonDeleteCsvRow = QtWidgets.QPushButton(self.groupBoxCsv)
        self.pushButtonDeleteCsvRow.setObjectName("pushButtonDeleteCsvRow")
        self.gridLayout_4.addWidget(self.pushButtonDeleteCsvRow, 0, 3, 1, 1)
        self.lineEditCsv = QtWidgets.QLineEdit(self.groupBoxCsv)
        self.lineEditCsv.setMaximumSize(QtCore.QSize(200, 16777215))
        self.lineEditCsv.setObjectName("lineEditCsv")
        self.gridLayout_4.addWidget(self.lineEditCsv, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem4, 0, 9, 1, 1)
        self.labelPathConversion = QtWidgets.QLabel(self.groupBoxCsv)
        self.labelPathConversion.setObjectName("labelPathConversion")
        self.gridLayout_4.addWidget(self.labelPathConversion, 0, 5, 1, 1)
        self.lineEditPathConversionTo = QtWidgets.QLineEdit(self.groupBoxCsv)
        self.lineEditPathConversionTo.setObjectName("lineEditPathConversionTo")
        self.gridLayout_4.addWidget(self.lineEditPathConversionTo, 0, 8, 1, 1)
        self.labePathConversion2 = QtWidgets.QLabel(self.groupBoxCsv)
        self.labePathConversion2.setObjectName("labePathConversion2")
        self.gridLayout_4.addWidget(self.labePathConversion2, 0, 7, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem5, 0, 4, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBoxCsv)
        self.tableViewImportCsv = QtWidgets.QTableView(self.tabImportCsv)
        self.tableViewImportCsv.setMinimumSize(QtCore.QSize(0, 200))
        self.tableViewImportCsv.setObjectName("tableViewImportCsv")
        self.verticalLayout_4.addWidget(self.tableViewImportCsv)
        self.plainTextEditLogCsv = QtWidgets.QPlainTextEdit(self.tabImportCsv)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plainTextEditLogCsv.sizePolicy().hasHeightForWidth())
        self.plainTextEditLogCsv.setSizePolicy(sizePolicy)
        self.plainTextEditLogCsv.setMinimumSize(QtCore.QSize(0, 40))
        self.plainTextEditLogCsv.setReadOnly(True)
        self.plainTextEditLogCsv.setObjectName("plainTextEditLogCsv")
        self.verticalLayout_4.addWidget(self.plainTextEditLogCsv)
        self.tabWidget.addTab(self.tabImportCsv, "")
        self.tabSettings = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabSettings.sizePolicy().hasHeightForWidth())
        self.tabSettings.setSizePolicy(sizePolicy)
        self.tabSettings.setObjectName("tabSettings")
        self.layoutWidget = QtWidgets.QWidget(self.tabSettings)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 10, 841, 811))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.groupBox_4 = QtWidgets.QGroupBox(self.layoutWidget)
        self.groupBox_4.setObjectName("groupBox_4")
        self.labelDbname = QtWidgets.QLabel(self.groupBox_4)
        self.labelDbname.setGeometry(QtCore.QRect(7, 92, 91, 20))
        self.labelDbname.setObjectName("labelDbname")
        self.lineEditDbname = QtWidgets.QLineEdit(self.groupBox_4)
        self.lineEditDbname.setGeometry(QtCore.QRect(120, 88, 211, 26))
        self.lineEditDbname.setText("")
        self.lineEditDbname.setObjectName("lineEditDbname")
        self.comboBoxDebug = QtWidgets.QComboBox(self.groupBox_4)
        self.comboBoxDebug.setGeometry(QtCore.QRect(120, 126, 251, 26))
        self.comboBoxDebug.setObjectName("comboBoxDebug")
        self.comboBoxDebug.addItem("")
        self.comboBoxDebug.addItem("")
        self.comboBoxDebug.addItem("")
        self.comboBoxDebug.addItem("")
        self.comboBoxDebug.addItem("")
        self.label = QtWidgets.QLabel(self.groupBox_4)
        self.label.setGeometry(QtCore.QRect(7, 130, 101, 18))
        self.label.setObjectName("label")
        self.labelDefaultTime = QtWidgets.QLabel(self.groupBox_4)
        self.labelDefaultTime.setGeometry(QtCore.QRect(7, 167, 111, 18))
        self.labelDefaultTime.setObjectName("labelDefaultTime")
        self.spinBoxDefaultTimeStart = QtWidgets.QSpinBox(self.groupBox_4)
        self.spinBoxDefaultTimeStart.setGeometry(QtCore.QRect(172, 163, 71, 27))
        self.spinBoxDefaultTimeStart.setMaximum(24)
        self.spinBoxDefaultTimeStart.setProperty("value", 20)
        self.spinBoxDefaultTimeStart.setObjectName("spinBoxDefaultTimeStart")
        self.spinBoxDefaultTimeEnd = QtWidgets.QSpinBox(self.groupBox_4)
        self.spinBoxDefaultTimeEnd.setGeometry(QtCore.QRect(300, 163, 71, 27))
        self.spinBoxDefaultTimeEnd.setMaximum(24)
        self.spinBoxDefaultTimeEnd.setProperty("value", 8)
        self.spinBoxDefaultTimeEnd.setObjectName("spinBoxDefaultTimeEnd")
        self.pushButtonSelectDb = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButtonSelectDb.setGeometry(QtCore.QRect(340, 88, 31, 26))
        self.pushButtonSelectDb.setText("")
        self.pushButtonSelectDb.setObjectName("pushButtonSelectDb")
        self.pushButtonSaveConfig = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButtonSaveConfig.setGeometry(QtCore.QRect(274, 280, 95, 26))
        self.pushButtonSaveConfig.setObjectName("pushButtonSaveConfig")
        self.label_5 = QtWidgets.QLabel(self.groupBox_4)
        self.label_5.setGeometry(QtCore.QRect(123, 167, 51, 18))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.groupBox_4)
        self.label_6.setGeometry(QtCore.QRect(270, 168, 31, 18))
        self.label_6.setObjectName("label_6")
        self.labelMonthsFilter = QtWidgets.QLabel(self.groupBox_4)
        self.labelMonthsFilter.setGeometry(QtCore.QRect(7, 204, 111, 18))
        self.labelMonthsFilter.setObjectName("labelMonthsFilter")
        self.comboBoxMonthsFilter = QtWidgets.QComboBox(self.groupBox_4)
        self.comboBoxMonthsFilter.setGeometry(QtCore.QRect(120, 201, 251, 26))
        self.comboBoxMonthsFilter.setObjectName("comboBoxMonthsFilter")
        self.comboBoxMonthsFilter.addItem("")
        self.comboBoxMonthsFilter.addItem("")
        self.comboBoxMonthsFilter.addItem("")
        self.comboBoxMonthsFilter.addItem("")
        self.comboBoxMonthsFilter.addItem("")
        self.lineEditModuleDir = QtWidgets.QLineEdit(self.groupBox_4)
        self.lineEditModuleDir.setGeometry(QtCore.QRect(120, 50, 251, 26))
        self.lineEditModuleDir.setReadOnly(True)
        self.lineEditModuleDir.setObjectName("lineEditModuleDir")
        self.label_7 = QtWidgets.QLabel(self.groupBox_4)
        self.label_7.setGeometry(QtCore.QRect(7, 54, 101, 18))
        self.label_7.setObjectName("label_7")
        self.labelPrecision = QtWidgets.QLabel(self.groupBox_4)
        self.labelPrecision.setGeometry(QtCore.QRect(7, 242, 111, 18))
        self.labelPrecision.setObjectName("labelPrecision")
        self.spinBoxPrecision = QtWidgets.QSpinBox(self.groupBox_4)
        self.spinBoxPrecision.setGeometry(QtCore.QRect(120, 238, 71, 27))
        self.spinBoxPrecision.setMaximum(4)
        self.spinBoxPrecision.setProperty("value", 2)
        self.spinBoxPrecision.setObjectName("spinBoxPrecision")
        self.gridLayout_7.addWidget(self.groupBox_4, 0, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.layoutWidget)
        self.groupBox_3.setObjectName("groupBox_3")
        self.lineEditFitsFile = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFile.setGeometry(QtCore.QRect(123, 100, 121, 26))
        self.lineEditFitsFile.setObjectName("lineEditFitsFile")
        self.labelFitsFile = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsFile.setGeometry(QtCore.QRect(10, 104, 91, 20))
        self.labelFitsFile.setObjectName("labelFitsFile")
        self.labelFitsTarget = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsTarget.setGeometry(QtCore.QRect(10, 144, 91, 20))
        self.labelFitsTarget.setObjectName("labelFitsTarget")
        self.lineEditFitsTarget = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsTarget.setGeometry(QtCore.QRect(123, 140, 121, 26))
        self.lineEditFitsTarget.setText("")
        self.lineEditFitsTarget.setObjectName("lineEditFitsTarget")
        self.labelFitsFrame = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsFrame.setGeometry(QtCore.QRect(10, 184, 91, 20))
        self.labelFitsFrame.setObjectName("labelFitsFrame")
        self.lineEditFitsFrame = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFrame.setGeometry(QtCore.QRect(123, 180, 121, 26))
        self.lineEditFitsFrame.setText("")
        self.lineEditFitsFrame.setObjectName("lineEditFitsFrame")
        self.lineEditFitsFilter = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFilter.setGeometry(QtCore.QRect(123, 221, 121, 26))
        self.lineEditFitsFilter.setText("")
        self.lineEditFitsFilter.setObjectName("lineEditFitsFilter")
        self.labelFitsFilter = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsFilter.setGeometry(QtCore.QRect(10, 225, 91, 20))
        self.labelFitsFilter.setObjectName("labelFitsFilter")
        self.labelFitsExposure = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsExposure.setGeometry(QtCore.QRect(10, 264, 91, 20))
        self.labelFitsExposure.setObjectName("labelFitsExposure")
        self.lineEditFitsExposure = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsExposure.setGeometry(QtCore.QRect(123, 260, 121, 26))
        self.lineEditFitsExposure.setText("")
        self.lineEditFitsExposure.setObjectName("lineEditFitsExposure")
        self.labelFitsTemp = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsTemp.setGeometry(QtCore.QRect(10, 304, 91, 20))
        self.labelFitsTemp.setObjectName("labelFitsTemp")
        self.lineEditFitsTemp = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsTemp.setGeometry(QtCore.QRect(123, 300, 121, 26))
        self.lineEditFitsTemp.setText("")
        self.lineEditFitsTemp.setObjectName("lineEditFitsTemp")
        self.labelFitsXbinning = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsXbinning.setGeometry(QtCore.QRect(10, 344, 91, 20))
        self.labelFitsXbinning.setObjectName("labelFitsXbinning")
        self.lineEditFitsXbinning = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsXbinning.setGeometry(QtCore.QRect(123, 340, 121, 26))
        self.lineEditFitsXbinning.setText("")
        self.lineEditFitsXbinning.setObjectName("lineEditFitsXbinning")
        self.labelFitsYbinning = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsYbinning.setGeometry(QtCore.QRect(10, 384, 91, 20))
        self.labelFitsYbinning.setObjectName("labelFitsYbinning")
        self.lineEditFitsYbinning = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsYbinning.setGeometry(QtCore.QRect(123, 380, 121, 26))
        self.lineEditFitsYbinning.setText("")
        self.lineEditFitsYbinning.setObjectName("lineEditFitsYbinning")
        self.lineEditFitsSitelat = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsSitelat.setGeometry(QtCore.QRect(123, 420, 121, 26))
        self.lineEditFitsSitelat.setText("")
        self.lineEditFitsSitelat.setObjectName("lineEditFitsSitelat")
        self.labelFitsSitelat = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsSitelat.setGeometry(QtCore.QRect(10, 424, 91, 20))
        self.labelFitsSitelat.setObjectName("labelFitsSitelat")
        self.lineEditFitsSitelong = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsSitelong.setGeometry(QtCore.QRect(123, 458, 121, 26))
        self.lineEditFitsSitelong.setText("")
        self.lineEditFitsSitelong.setObjectName("lineEditFitsSitelong")
        self.labelFitsSitelong = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsSitelong.setGeometry(QtCore.QRect(10, 462, 91, 20))
        self.labelFitsSitelong.setObjectName("labelFitsSitelong")
        self.labelFitsRa = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsRa.setGeometry(QtCore.QRect(10, 504, 91, 20))
        self.labelFitsRa.setObjectName("labelFitsRa")
        self.lineEditFitsRa = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsRa.setGeometry(QtCore.QRect(123, 500, 121, 26))
        self.lineEditFitsRa.setText("")
        self.lineEditFitsRa.setObjectName("lineEditFitsRa")
        self.labelFitsDec = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsDec.setGeometry(QtCore.QRect(10, 544, 91, 20))
        self.labelFitsDec.setObjectName("labelFitsDec")
        self.lineEditFitsDec = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsDec.setGeometry(QtCore.QRect(123, 540, 121, 26))
        self.lineEditFitsDec.setText("")
        self.lineEditFitsDec.setObjectName("lineEditFitsDec")
        self.labelFitsDate = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsDate.setGeometry(QtCore.QRect(10, 584, 91, 20))
        self.labelFitsDate.setObjectName("labelFitsDate")
        self.lineEditFitsDate = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsDate.setGeometry(QtCore.QRect(123, 580, 121, 26))
        self.lineEditFitsDate.setText("")
        self.lineEditFitsDate.setObjectName("lineEditFitsDate")
        self.lineEditFitsGain = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsGain.setGeometry(QtCore.QRect(123, 618, 121, 26))
        self.lineEditFitsGain.setText("")
        self.lineEditFitsGain.setObjectName("lineEditFitsGain")
        self.labelFitsGain = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsGain.setGeometry(QtCore.QRect(10, 622, 91, 20))
        self.labelFitsGain.setObjectName("labelFitsGain")
        self.lineEditFitsOffset = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsOffset.setGeometry(QtCore.QRect(123, 656, 121, 26))
        self.lineEditFitsOffset.setText("")
        self.lineEditFitsOffset.setObjectName("lineEditFitsOffset")
        self.labelFitsOffset = QtWidgets.QLabel(self.groupBox_3)
        self.labelFitsOffset.setGeometry(QtCore.QRect(10, 660, 91, 20))
        self.labelFitsOffset.setObjectName("labelFitsOffset")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setGeometry(QtCore.QRect(133, 78, 121, 18))
        self.label_2.setObjectName("label_2")
        self.lineEditFitsFileDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFileDefault.setGeometry(QtCore.QRect(250, 100, 121, 26))
        self.lineEditFitsFileDefault.setObjectName("lineEditFitsFileDefault")
        self.lineEditFitsTargetDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsTargetDefault.setGeometry(QtCore.QRect(250, 140, 121, 26))
        self.lineEditFitsTargetDefault.setText("")
        self.lineEditFitsTargetDefault.setObjectName("lineEditFitsTargetDefault")
        self.lineEditFitsFrameDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFrameDefault.setGeometry(QtCore.QRect(250, 180, 121, 26))
        self.lineEditFitsFrameDefault.setText("")
        self.lineEditFitsFrameDefault.setObjectName("lineEditFitsFrameDefault")
        self.lineEditFitsFilterDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsFilterDefault.setGeometry(QtCore.QRect(250, 220, 121, 26))
        self.lineEditFitsFilterDefault.setText("")
        self.lineEditFitsFilterDefault.setObjectName("lineEditFitsFilterDefault")
        self.lineEditFitsExposureDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsExposureDefault.setGeometry(QtCore.QRect(250, 260, 121, 26))
        self.lineEditFitsExposureDefault.setText("")
        self.lineEditFitsExposureDefault.setObjectName("lineEditFitsExposureDefault")
        self.lineEditFitsTempDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsTempDefault.setGeometry(QtCore.QRect(250, 300, 121, 26))
        self.lineEditFitsTempDefault.setText("")
        self.lineEditFitsTempDefault.setObjectName("lineEditFitsTempDefault")
        self.lineEditFitsXbinningDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsXbinningDefault.setGeometry(QtCore.QRect(250, 340, 121, 26))
        self.lineEditFitsXbinningDefault.setText("")
        self.lineEditFitsXbinningDefault.setObjectName("lineEditFitsXbinningDefault")
        self.lineEditFitsYbinningDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsYbinningDefault.setGeometry(QtCore.QRect(250, 380, 121, 26))
        self.lineEditFitsYbinningDefault.setText("")
        self.lineEditFitsYbinningDefault.setObjectName("lineEditFitsYbinningDefault")
        self.lineEditFitsSitelatDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsSitelatDefault.setGeometry(QtCore.QRect(250, 420, 121, 26))
        self.lineEditFitsSitelatDefault.setText("")
        self.lineEditFitsSitelatDefault.setObjectName("lineEditFitsSitelatDefault")
        self.lineEditFitsSitelongDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsSitelongDefault.setGeometry(QtCore.QRect(250, 458, 121, 26))
        self.lineEditFitsSitelongDefault.setText("")
        self.lineEditFitsSitelongDefault.setObjectName("lineEditFitsSitelongDefault")
        self.lineEditFitsRaDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsRaDefault.setGeometry(QtCore.QRect(250, 500, 121, 26))
        self.lineEditFitsRaDefault.setText("")
        self.lineEditFitsRaDefault.setObjectName("lineEditFitsRaDefault")
        self.lineEditFitsDecDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsDecDefault.setGeometry(QtCore.QRect(250, 540, 121, 26))
        self.lineEditFitsDecDefault.setText("")
        self.lineEditFitsDecDefault.setObjectName("lineEditFitsDecDefault")
        self.lineEditFitsDateDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsDateDefault.setGeometry(QtCore.QRect(250, 580, 121, 26))
        self.lineEditFitsDateDefault.setText("")
        self.lineEditFitsDateDefault.setObjectName("lineEditFitsDateDefault")
        self.lineEditFitsGainDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsGainDefault.setGeometry(QtCore.QRect(250, 618, 121, 26))
        self.lineEditFitsGainDefault.setText("")
        self.lineEditFitsGainDefault.setObjectName("lineEditFitsGainDefault")
        self.lineEditFitsOffsetDefault = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditFitsOffsetDefault.setGeometry(QtCore.QRect(250, 656, 121, 26))
        self.lineEditFitsOffsetDefault.setText("")
        self.lineEditFitsOffsetDefault.setObjectName("lineEditFitsOffsetDefault")
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setGeometry(QtCore.QRect(259, 78, 121, 18))
        self.label_3.setObjectName("label_3")
        self.pushButtonSaveProfile = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButtonSaveProfile.setGeometry(QtCore.QRect(274, 770, 95, 26))
        self.pushButtonSaveProfile.setObjectName("pushButtonSaveProfile")
        self.lineEditProfileName = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEditProfileName.setGeometry(QtCore.QRect(124, 730, 246, 26))
        self.lineEditProfileName.setObjectName("lineEditProfileName")
        self.checkBoxFitsFile = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsFile.setGeometry(QtCore.QRect(380, 101, 21, 24))
        self.checkBoxFitsFile.setText("")
        self.checkBoxFitsFile.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsFile.setObjectName("checkBoxFitsFile")
        self.label_4 = QtWidgets.QLabel(self.groupBox_3)
        self.label_4.setGeometry(QtCore.QRect(374, 78, 41, 18))
        self.label_4.setObjectName("label_4")
        self.checkBoxFitsTarget = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsTarget.setGeometry(QtCore.QRect(380, 140, 21, 24))
        self.checkBoxFitsTarget.setText("")
        self.checkBoxFitsTarget.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsTarget.setObjectName("checkBoxFitsTarget")
        self.checkBoxFitsFrame = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsFrame.setGeometry(QtCore.QRect(380, 180, 21, 24))
        self.checkBoxFitsFrame.setText("")
        self.checkBoxFitsFrame.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsFrame.setObjectName("checkBoxFitsFrame")
        self.checkBoxFitsFilter = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsFilter.setGeometry(QtCore.QRect(380, 221, 21, 24))
        self.checkBoxFitsFilter.setText("")
        self.checkBoxFitsFilter.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsFilter.setObjectName("checkBoxFitsFilter")
        self.checkBoxFitsTemp = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsTemp.setGeometry(QtCore.QRect(380, 301, 21, 24))
        self.checkBoxFitsTemp.setText("")
        self.checkBoxFitsTemp.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsTemp.setObjectName("checkBoxFitsTemp")
        self.checkBoxFitsYbinning = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsYbinning.setGeometry(QtCore.QRect(380, 381, 21, 24))
        self.checkBoxFitsYbinning.setText("")
        self.checkBoxFitsYbinning.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsYbinning.setObjectName("checkBoxFitsYbinning")
        self.checkBoxFitsXbinning = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsXbinning.setGeometry(QtCore.QRect(380, 341, 21, 24))
        self.checkBoxFitsXbinning.setText("")
        self.checkBoxFitsXbinning.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsXbinning.setObjectName("checkBoxFitsXbinning")
        self.checkBoxFitsExposure = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsExposure.setGeometry(QtCore.QRect(380, 261, 21, 24))
        self.checkBoxFitsExposure.setText("")
        self.checkBoxFitsExposure.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsExposure.setObjectName("checkBoxFitsExposure")
        self.checkBoxFitsSitelong = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsSitelong.setGeometry(QtCore.QRect(380, 459, 21, 24))
        self.checkBoxFitsSitelong.setText("")
        self.checkBoxFitsSitelong.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsSitelong.setObjectName("checkBoxFitsSitelong")
        self.checkBoxFitsDec = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsDec.setGeometry(QtCore.QRect(380, 541, 21, 24))
        self.checkBoxFitsDec.setText("")
        self.checkBoxFitsDec.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsDec.setObjectName("checkBoxFitsDec")
        self.checkBoxFitsRa = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsRa.setGeometry(QtCore.QRect(380, 501, 21, 24))
        self.checkBoxFitsRa.setText("")
        self.checkBoxFitsRa.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsRa.setObjectName("checkBoxFitsRa")
        self.checkBoxFitsSitelat = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsSitelat.setGeometry(QtCore.QRect(380, 422, 21, 24))
        self.checkBoxFitsSitelat.setText("")
        self.checkBoxFitsSitelat.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsSitelat.setObjectName("checkBoxFitsSitelat")
        self.checkBoxFitsGain = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsGain.setGeometry(QtCore.QRect(380, 619, 21, 24))
        self.checkBoxFitsGain.setText("")
        self.checkBoxFitsGain.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsGain.setObjectName("checkBoxFitsGain")
        self.checkBoxFitsOffset = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsOffset.setGeometry(QtCore.QRect(380, 657, 21, 24))
        self.checkBoxFitsOffset.setText("")
        self.checkBoxFitsOffset.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsOffset.setObjectName("checkBoxFitsOffset")
        self.checkBoxFitsDate = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBoxFitsDate.setGeometry(QtCore.QRect(380, 581, 21, 24))
        self.checkBoxFitsDate.setText("")
        self.checkBoxFitsDate.setIconSize(QtCore.QSize(16, 16))
        self.checkBoxFitsDate.setObjectName("checkBoxFitsDate")
        self.comboBoxProfile = QtWidgets.QComboBox(self.groupBox_3)
        self.comboBoxProfile.setGeometry(QtCore.QRect(123, 40, 246, 26))
        self.comboBoxProfile.setObjectName("comboBoxProfile")
        self.labelProfile = QtWidgets.QLabel(self.groupBox_3)
        self.labelProfile.setGeometry(QtCore.QRect(7, 44, 111, 18))
        self.labelProfile.setObjectName("labelProfile")
        self.comboBoxCoordFormat = QtWidgets.QComboBox(self.groupBox_3)
        self.comboBoxCoordFormat.setGeometry(QtCore.QRect(123, 690, 246, 26))
        self.comboBoxCoordFormat.setObjectName("comboBoxCoordFormat")
        self.comboBoxCoordFormat.addItem("")
        self.comboBoxCoordFormat.addItem("")
        self.labelCoordFormat = QtWidgets.QLabel(self.groupBox_3)
        self.labelCoordFormat.setGeometry(QtCore.QRect(10, 693, 111, 18))
        self.labelCoordFormat.setObjectName("labelCoordFormat")
        self.labelCoordFormat_2 = QtWidgets.QLabel(self.groupBox_3)
        self.labelCoordFormat_2.setGeometry(QtCore.QRect(10, 734, 101, 18))
        self.labelCoordFormat_2.setObjectName("labelCoordFormat_2")
        self.gridLayout_7.addWidget(self.groupBox_3, 0, 1, 2, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.layoutWidget)
        self.groupBox_5.setObjectName("groupBox_5")
        self.labelFilterR = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterR.setGeometry(QtCore.QRect(7, 74, 91, 20))
        self.labelFilterR.setObjectName("labelFilterR")
        self.labelFilterL = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterL.setGeometry(QtCore.QRect(7, 34, 91, 20))
        self.labelFilterL.setObjectName("labelFilterL")
        self.labelFilterHa = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterHa.setGeometry(QtCore.QRect(7, 194, 91, 20))
        self.labelFilterHa.setObjectName("labelFilterHa")
        self.lineEditFilterLpr = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterLpr.setGeometry(QtCore.QRect(120, 310, 251, 26))
        self.lineEditFilterLpr.setText("")
        self.lineEditFilterLpr.setObjectName("lineEditFilterLpr")
        self.labelFilterOiii = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterOiii.setGeometry(QtCore.QRect(7, 234, 91, 20))
        self.labelFilterOiii.setObjectName("labelFilterOiii")
        self.labelFilterLpr = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterLpr.setGeometry(QtCore.QRect(7, 314, 91, 20))
        self.labelFilterLpr.setObjectName("labelFilterLpr")
        self.lineEditFilterR = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterR.setGeometry(QtCore.QRect(120, 70, 251, 26))
        self.lineEditFilterR.setText("")
        self.lineEditFilterR.setObjectName("lineEditFilterR")
        self.lineEditFilterL = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterL.setGeometry(QtCore.QRect(120, 30, 251, 26))
        self.lineEditFilterL.setObjectName("lineEditFilterL")
        self.lineEditFilterOiii = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterOiii.setGeometry(QtCore.QRect(120, 230, 251, 26))
        self.lineEditFilterOiii.setText("")
        self.lineEditFilterOiii.setObjectName("lineEditFilterOiii")
        self.lineEditFilterG = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterG.setGeometry(QtCore.QRect(120, 110, 251, 26))
        self.lineEditFilterG.setText("")
        self.lineEditFilterG.setObjectName("lineEditFilterG")
        self.labelFilterB = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterB.setGeometry(QtCore.QRect(7, 155, 91, 20))
        self.labelFilterB.setObjectName("labelFilterB")
        self.labelFilterG = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterG.setGeometry(QtCore.QRect(7, 114, 91, 20))
        self.labelFilterG.setObjectName("labelFilterG")
        self.labelFilterSii = QtWidgets.QLabel(self.groupBox_5)
        self.labelFilterSii.setGeometry(QtCore.QRect(7, 274, 91, 20))
        self.labelFilterSii.setObjectName("labelFilterSii")
        self.lineEditFilterSii = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterSii.setGeometry(QtCore.QRect(120, 270, 251, 26))
        self.lineEditFilterSii.setText("")
        self.lineEditFilterSii.setObjectName("lineEditFilterSii")
        self.lineEditFilterB = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterB.setGeometry(QtCore.QRect(120, 151, 251, 26))
        self.lineEditFilterB.setText("")
        self.lineEditFilterB.setObjectName("lineEditFilterB")
        self.lineEditFilterHa = QtWidgets.QLineEdit(self.groupBox_5)
        self.lineEditFilterHa.setGeometry(QtCore.QRect(120, 190, 251, 26))
        self.lineEditFilterHa.setText("")
        self.lineEditFilterHa.setObjectName("lineEditFilterHa")
        self.pushButtonSaveFilter = QtWidgets.QPushButton(self.groupBox_5)
        self.pushButtonSaveFilter.setGeometry(QtCore.QRect(274, 350, 95, 26))
        self.pushButtonSaveFilter.setObjectName("pushButtonSaveFilter")
        self.gridLayout_7.addWidget(self.groupBox_5, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tabSettings, "")
        self.fitsHeaderTab = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fitsHeaderTab.sizePolicy().hasHeightForWidth())
        self.fitsHeaderTab.setSizePolicy(sizePolicy)
        self.fitsHeaderTab.setObjectName("fitsHeaderTab")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.fitsHeaderTab)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.plainTextEditFitsHeader = QtWidgets.QPlainTextEdit(self.fitsHeaderTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plainTextEditFitsHeader.sizePolicy().hasHeightForWidth())
        self.plainTextEditFitsHeader.setSizePolicy(sizePolicy)
        self.plainTextEditFitsHeader.setMinimumSize(QtCore.QSize(0, 200))
        self.plainTextEditFitsHeader.setReadOnly(True)
        self.plainTextEditFitsHeader.setObjectName("plainTextEditFitsHeader")
        self.gridLayout_6.addWidget(self.plainTextEditFitsHeader, 1, 0, 1, 1)
        self.plainTextEditMsg = QtWidgets.QPlainTextEdit(self.fitsHeaderTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plainTextEditMsg.sizePolicy().hasHeightForWidth())
        self.plainTextEditMsg.setSizePolicy(sizePolicy)
        self.plainTextEditMsg.setMinimumSize(QtCore.QSize(0, 40))
        self.plainTextEditMsg.setObjectName("plainTextEditMsg")
        self.gridLayout_6.addWidget(self.plainTextEditMsg, 2, 0, 1, 1)
        self.groupBoxFitsHeader = QtWidgets.QGroupBox(self.fitsHeaderTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxFitsHeader.sizePolicy().hasHeightForWidth())
        self.groupBoxFitsHeader.setSizePolicy(sizePolicy)
        self.groupBoxFitsHeader.setMinimumSize(QtCore.QSize(0, 80))
        self.groupBoxFitsHeader.setObjectName("groupBoxFitsHeader")
        self.pushButtonFitsHeader = QtWidgets.QPushButton(self.groupBoxFitsHeader)
        self.pushButtonFitsHeader.setGeometry(QtCore.QRect(330, 30, 105, 26))
        self.pushButtonFitsHeader.setObjectName("pushButtonFitsHeader")
        self.lineEditFitsHeader = QtWidgets.QLineEdit(self.groupBoxFitsHeader)
        self.lineEditFitsHeader.setGeometry(QtCore.QRect(10, 30, 311, 26))
        self.lineEditFitsHeader.setObjectName("lineEditFitsHeader")
        self.gridLayout_6.addWidget(self.groupBoxFitsHeader, 0, 0, 1, 1)
        self.tabWidget.addTab(self.fitsHeaderTab, "")
        self.gridLayout.addWidget(self.tabWidget, 0, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.comboBoxSnrweight.setItemText(0, _translate("Dialog", "="))
        self.comboBoxSnrweight.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxSnrweight.setItemText(2, _translate("Dialog", ">"))
        self.labelExposure.setText(_translate("Dialog", "Exposure"))
        self.labelSnrweight.setText(_translate("Dialog", "SNR"))
        self.comboBoxExposure.setItemText(0, _translate("Dialog", "="))
        self.comboBoxExposure.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxExposure.setItemText(2, _translate("Dialog", ">"))
        self.labelEccentricity.setText(_translate("Dialog", "Eccentricity"))
        self.labelFwhm.setText(_translate("Dialog", "FWHM"))
        self.pushButtonDeleteRow.setText(_translate("Dialog", "Delete Row"))
        self.labelStartDate.setText(_translate("Dialog", "Start"))
        self.comboBoxNoise.setItemText(0, _translate("Dialog", "="))
        self.comboBoxNoise.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxNoise.setItemText(2, _translate("Dialog", ">"))
        self.pushButtonGraph.setText(_translate("Dialog", "Charts"))
        self.labelNoise.setText(_translate("Dialog", "Noise"))
        self.pushButtonLastNight.setText(_translate("Dialog", "Select Night"))
        self.labelFrame.setText(_translate("Dialog", "Frame"))
        self.comboBoxAz.setItemText(0, _translate("Dialog", "="))
        self.comboBoxAz.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxAz.setItemText(2, _translate("Dialog", ">"))
        self.comboBoxEccentricity.setItemText(0, _translate("Dialog", "="))
        self.comboBoxEccentricity.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxEccentricity.setItemText(2, _translate("Dialog", ">"))
        self.labelFilter.setText(_translate("Dialog", "Filter"))
        self.labelTarget.setText(_translate("Dialog", "Target"))
        self.comboBoxAlt.setItemText(0, _translate("Dialog", "="))
        self.comboBoxAlt.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxAlt.setItemText(2, _translate("Dialog", ">"))
        self.comboBoxFwhm.setItemText(0, _translate("Dialog", "="))
        self.comboBoxFwhm.setItemText(1, _translate("Dialog", "<"))
        self.comboBoxFwhm.setItemText(2, _translate("Dialog", ">"))
        self.labelAz.setText(_translate("Dialog", "AZ"))
        self.labelAlt.setText(_translate("Dialog", "ALT"))
        self.labelEndDate.setText(_translate("Dialog", "End"))
        self.pushButtonDashboard.setText(_translate("Dialog", "Dashboard"))
        self.pushButtonExportCsv.setText(_translate("Dialog", "Export Data"))
        self.lineEditMeanNoise.setWhatsThis(_translate("Dialog", "Noise Mean Value"))
        self.labelMeanEccentricity.setText(_translate("Dialog", "Eccentricity"))
        self.labelMeanNoise.setText(_translate("Dialog", "Noise"))
        self.lineEditMeanFwhm.setWhatsThis(_translate("Dialog", "Fwhm Mean Value"))
        self.labelCurrentDb.setText(_translate("Dialog", "Current DB:"))
        self.lineEditSigmaSnr.setWhatsThis(_translate("Dialog", "Snr Weight Standard Dev"))
        self.labelMeanAlt.setText(_translate("Dialog", "Alt"))
        self.lineEditSigmaNoise.setWhatsThis(_translate("Dialog", "Noise Standard Dev"))
        self.labelTotExposure.setText(_translate("Dialog", "Tot"))
        self.lineEditTotExposure.setWhatsThis(_translate("Dialog", "Total Hours"))
        self.lineEditMeanSnr.setWhatsThis(_translate("Dialog", "Snr Weight Mean Value"))
        self.lineEditMeanEccentricity.setWhatsThis(_translate("Dialog", "Eccentricity Mean Value"))
        self.lineEditSigmaAlt.setWhatsThis(_translate("Dialog", "Alt Standard Dev"))
        self.labelMeanFwhm.setText(_translate("Dialog", "FWHM"))
        self.lineEditTotImages.setWhatsThis(_translate("Dialog", "Total Hours"))
        self.lineEditMeanAlt.setWhatsThis(_translate("Dialog", "Alt Mean Value"))
        self.labelMeanSnr.setText(_translate("Dialog", "SNR"))
        self.lineEditSigmaEccentricity.setWhatsThis(_translate("Dialog", "Eccentricity Standard Dev"))
        self.lineEditSigmaFwhm.setWhatsThis(_translate("Dialog", "Fwhm Standard Dev"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabImages), _translate("Dialog", "Images"))
        self.groupBoxFitsImport.setTitle(_translate("Dialog", "FITS File Import"))
        self.pushButtonLoadFits.setText(_translate("Dialog", "Load Files"))
        self.pushButtonSaveFits.setText(_translate("Dialog", "Insert DB"))
        self.pushButtonDeleteFitsRow.setText(_translate("Dialog", "Delete row"))
        self.pushButtonChooseFitsDir.setText(_translate("Dialog", "Choose Dir"))
        self.labelOverrideTarget.setText(_translate("Dialog", "Override Target Name on Insert"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabImportFits), _translate("Dialog", "Import FITS"))
        self.groupBoxCsv.setTitle(_translate("Dialog", "PixInsight SubFrameSelector CSV Import"))
        self.pushButtonChooseCsv.setText(_translate("Dialog", "Choose CSV"))
        self.pushButtonSaveCsv.setText(_translate("Dialog", "Insert DB"))
        self.pushButtonDeleteCsvRow.setText(_translate("Dialog", "Delete row"))
        self.labelPathConversion.setText(_translate("Dialog", "Apply Path Conversion From: "))
        self.labePathConversion2.setText(_translate("Dialog", "To:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabImportCsv), _translate("Dialog", "Import CSV"))
        self.groupBox_4.setTitle(_translate("Dialog", "Config"))
        self.labelDbname.setText(_translate("Dialog", "Database"))
        self.comboBoxDebug.setItemText(0, _translate("Dialog", "DEBUG"))
        self.comboBoxDebug.setItemText(1, _translate("Dialog", "INFO"))
        self.comboBoxDebug.setItemText(2, _translate("Dialog", "WARNING"))
        self.comboBoxDebug.setItemText(3, _translate("Dialog", "ERROR"))
        self.comboBoxDebug.setItemText(4, _translate("Dialog", "CRITICAL"))
        self.label.setText(_translate("Dialog", "Debug Level"))
        self.labelDefaultTime.setText(_translate("Dialog", "Obs Time Hrs"))
        self.pushButtonSaveConfig.setText(_translate("Dialog", "Save"))
        self.label_5.setText(_translate("Dialog", "From"))
        self.label_6.setText(_translate("Dialog", "To"))
        self.labelMonthsFilter.setText(_translate("Dialog", "Filter Months"))
        self.comboBoxMonthsFilter.setItemText(0, _translate("Dialog", "3"))
        self.comboBoxMonthsFilter.setItemText(1, _translate("Dialog", "6"))
        self.comboBoxMonthsFilter.setItemText(2, _translate("Dialog", "12"))
        self.comboBoxMonthsFilter.setItemText(3, _translate("Dialog", "24"))
        self.comboBoxMonthsFilter.setItemText(4, _translate("Dialog", "48"))
        self.label_7.setText(_translate("Dialog", "AstrDom Dir"))
        self.labelPrecision.setText(_translate("Dialog", "Precision"))
        self.groupBox_3.setTitle(_translate("Dialog", "FITS Profiles"))
        self.labelFitsFile.setText(_translate("Dialog", "File Name"))
        self.labelFitsTarget.setText(_translate("Dialog", "Target"))
        self.labelFitsFrame.setText(_translate("Dialog", "Frame Type"))
        self.labelFitsFilter.setText(_translate("Dialog", "Filter"))
        self.labelFitsExposure.setText(_translate("Dialog", "Exposure"))
        self.labelFitsTemp.setText(_translate("Dialog", "CCD Temp"))
        self.labelFitsXbinning.setText(_translate("Dialog", "X Bin"))
        self.labelFitsYbinning.setText(_translate("Dialog", "Y Bin"))
        self.labelFitsSitelat.setText(_translate("Dialog", "Site Lat"))
        self.labelFitsSitelong.setText(_translate("Dialog", "Site Long"))
        self.labelFitsRa.setText(_translate("Dialog", "RA"))
        self.labelFitsDec.setText(_translate("Dialog", "DEC"))
        self.labelFitsDate.setText(_translate("Dialog", "Obs Date"))
        self.labelFitsGain.setText(_translate("Dialog", "Gain"))
        self.labelFitsOffset.setText(_translate("Dialog", "Offset"))
        self.label_2.setText(_translate("Dialog", "FITS Keyword"))
        self.label_3.setText(_translate("Dialog", "Default Value"))
        self.pushButtonSaveProfile.setText(_translate("Dialog", "Save"))
        self.checkBoxFitsFile.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.label_4.setText(_translate("Dialog", "Hide"))
        self.checkBoxFitsTarget.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsFrame.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsFilter.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsTemp.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsYbinning.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsXbinning.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsExposure.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsSitelong.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsDec.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsRa.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsSitelat.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsGain.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsOffset.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.checkBoxFitsDate.setShortcut(_translate("Dialog", "Ctrl+C, Ctrl+V"))
        self.labelProfile.setText(_translate("Dialog", "Choose Profile"))
        self.comboBoxCoordFormat.setItemText(0, _translate("Dialog", "Decimal"))
        self.comboBoxCoordFormat.setItemText(1, _translate("Dialog", "Hour Angle"))
        self.labelCoordFormat.setText(_translate("Dialog", "Coord Format"))
        self.labelCoordFormat_2.setText(_translate("Dialog", "Profile Name"))
        self.groupBox_5.setTitle(_translate("Dialog", "Filter Keywords"))
        self.labelFilterR.setText(_translate("Dialog", "Red"))
        self.labelFilterL.setText(_translate("Dialog", "Luminance"))
        self.labelFilterHa.setText(_translate("Dialog", "Halpha"))
        self.labelFilterOiii.setText(_translate("Dialog", "Oiii"))
        self.labelFilterLpr.setText(_translate("Dialog", "LPR"))
        self.labelFilterB.setText(_translate("Dialog", "Blue"))
        self.labelFilterG.setText(_translate("Dialog", "Green"))
        self.labelFilterSii.setText(_translate("Dialog", "Sii"))
        self.pushButtonSaveFilter.setText(_translate("Dialog", "Save"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabSettings), _translate("Dialog", "Settings"))
        self.groupBoxFitsHeader.setTitle(_translate("Dialog", "FITS File Header Parser"))
        self.pushButtonFitsHeader.setText(_translate("Dialog", "Choose File"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.fitsHeaderTab), _translate("Dialog", "FITS Header"))
