# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'imageDetailWindow.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(755, 1011)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.MplWidget = QtWidgets.QWidget(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget.sizePolicy().hasHeightForWidth())
        self.MplWidget.setSizePolicy(sizePolicy)
        self.MplWidget.setMinimumSize(QtCore.QSize(0, 300))
        self.MplWidget.setObjectName("MplWidget")
        self.verticalLayout.addWidget(self.MplWidget)
        self.groupBox = QtWidgets.QGroupBox(Dialog)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.labelFile = QtWidgets.QLabel(self.groupBox)
        self.labelFile.setObjectName("labelFile")
        self.gridLayout.addWidget(self.labelFile, 0, 0, 1, 1)
        self.labelHash = QtWidgets.QLabel(self.groupBox)
        self.labelHash.setObjectName("labelHash")
        self.gridLayout.addWidget(self.labelHash, 1, 0, 1, 1)
        self.labelFileTarget = QtWidgets.QLabel(self.groupBox)
        self.labelFileTarget.setObjectName("labelFileTarget")
        self.gridLayout.addWidget(self.labelFileTarget, 2, 0, 1, 1)
        self.lineEditTarget = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditTarget.sizePolicy().hasHeightForWidth())
        self.lineEditTarget.setSizePolicy(sizePolicy)
        self.lineEditTarget.setObjectName("lineEditTarget")
        self.gridLayout.addWidget(self.lineEditTarget, 2, 1, 1, 1)
        self.labelFileDate = QtWidgets.QLabel(self.groupBox)
        self.labelFileDate.setObjectName("labelFileDate")
        self.gridLayout.addWidget(self.labelFileDate, 2, 2, 1, 1)
        self.lineEditDate = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditDate.sizePolicy().hasHeightForWidth())
        self.lineEditDate.setSizePolicy(sizePolicy)
        self.lineEditDate.setObjectName("lineEditDate")
        self.gridLayout.addWidget(self.lineEditDate, 2, 3, 1, 1)
        self.labelFrame = QtWidgets.QLabel(self.groupBox)
        self.labelFrame.setObjectName("labelFrame")
        self.gridLayout.addWidget(self.labelFrame, 3, 0, 1, 1)
        self.lineEditFrame = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditFrame.sizePolicy().hasHeightForWidth())
        self.lineEditFrame.setSizePolicy(sizePolicy)
        self.lineEditFrame.setObjectName("lineEditFrame")
        self.gridLayout.addWidget(self.lineEditFrame, 3, 1, 1, 1)
        self.labelGain = QtWidgets.QLabel(self.groupBox)
        self.labelGain.setObjectName("labelGain")
        self.gridLayout.addWidget(self.labelGain, 3, 2, 1, 1)
        self.lineEditGain = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditGain.sizePolicy().hasHeightForWidth())
        self.lineEditGain.setSizePolicy(sizePolicy)
        self.lineEditGain.setObjectName("lineEditGain")
        self.gridLayout.addWidget(self.lineEditGain, 3, 3, 1, 1)
        self.labelFilter = QtWidgets.QLabel(self.groupBox)
        self.labelFilter.setObjectName("labelFilter")
        self.gridLayout.addWidget(self.labelFilter, 4, 0, 1, 1)
        self.lineEditFilter = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditFilter.sizePolicy().hasHeightForWidth())
        self.lineEditFilter.setSizePolicy(sizePolicy)
        self.lineEditFilter.setObjectName("lineEditFilter")
        self.gridLayout.addWidget(self.lineEditFilter, 4, 1, 1, 1)
        self.labelFileOffset = QtWidgets.QLabel(self.groupBox)
        self.labelFileOffset.setObjectName("labelFileOffset")
        self.gridLayout.addWidget(self.labelFileOffset, 4, 2, 1, 1)
        self.lineEditOffset = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditOffset.sizePolicy().hasHeightForWidth())
        self.lineEditOffset.setSizePolicy(sizePolicy)
        self.lineEditOffset.setObjectName("lineEditOffset")
        self.gridLayout.addWidget(self.lineEditOffset, 4, 3, 1, 1)
        self.labelExposure = QtWidgets.QLabel(self.groupBox)
        self.labelExposure.setObjectName("labelExposure")
        self.gridLayout.addWidget(self.labelExposure, 5, 0, 1, 1)
        self.lineEditExposure = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditExposure.sizePolicy().hasHeightForWidth())
        self.lineEditExposure.setSizePolicy(sizePolicy)
        self.lineEditExposure.setObjectName("lineEditExposure")
        self.gridLayout.addWidget(self.lineEditExposure, 5, 1, 1, 1)
        self.labelSubframeScale = QtWidgets.QLabel(self.groupBox)
        self.labelSubframeScale.setObjectName("labelSubframeScale")
        self.gridLayout.addWidget(self.labelSubframeScale, 5, 2, 1, 1)
        self.lineEditSubframeScale = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSubframeScale.sizePolicy().hasHeightForWidth())
        self.lineEditSubframeScale.setSizePolicy(sizePolicy)
        self.lineEditSubframeScale.setObjectName("lineEditSubframeScale")
        self.gridLayout.addWidget(self.lineEditSubframeScale, 5, 3, 1, 1)
        self.labelTemp = QtWidgets.QLabel(self.groupBox)
        self.labelTemp.setObjectName("labelTemp")
        self.gridLayout.addWidget(self.labelTemp, 6, 0, 1, 1)
        self.lineEditTemp = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditTemp.sizePolicy().hasHeightForWidth())
        self.lineEditTemp.setSizePolicy(sizePolicy)
        self.lineEditTemp.setObjectName("lineEditTemp")
        self.gridLayout.addWidget(self.lineEditTemp, 6, 1, 1, 1)
        self.labelCameraGain = QtWidgets.QLabel(self.groupBox)
        self.labelCameraGain.setObjectName("labelCameraGain")
        self.gridLayout.addWidget(self.labelCameraGain, 6, 2, 1, 1)
        self.lineEditCameraGain = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditCameraGain.sizePolicy().hasHeightForWidth())
        self.lineEditCameraGain.setSizePolicy(sizePolicy)
        self.lineEditCameraGain.setObjectName("lineEditCameraGain")
        self.gridLayout.addWidget(self.lineEditCameraGain, 6, 3, 1, 1)
        self.labelXBinning = QtWidgets.QLabel(self.groupBox)
        self.labelXBinning.setObjectName("labelXBinning")
        self.gridLayout.addWidget(self.labelXBinning, 7, 0, 1, 1)
        self.lineEditXbinning = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditXbinning.sizePolicy().hasHeightForWidth())
        self.lineEditXbinning.setSizePolicy(sizePolicy)
        self.lineEditXbinning.setObjectName("lineEditXbinning")
        self.gridLayout.addWidget(self.lineEditXbinning, 7, 1, 1, 1)
        self.labelCameraResolution = QtWidgets.QLabel(self.groupBox)
        self.labelCameraResolution.setObjectName("labelCameraResolution")
        self.gridLayout.addWidget(self.labelCameraResolution, 7, 2, 1, 1)
        self.lineEditCameraResolution = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditCameraResolution.sizePolicy().hasHeightForWidth())
        self.lineEditCameraResolution.setSizePolicy(sizePolicy)
        self.lineEditCameraResolution.setObjectName("lineEditCameraResolution")
        self.gridLayout.addWidget(self.lineEditCameraResolution, 7, 3, 1, 1)
        self.labelYbinning = QtWidgets.QLabel(self.groupBox)
        self.labelYbinning.setObjectName("labelYbinning")
        self.gridLayout.addWidget(self.labelYbinning, 8, 0, 1, 1)
        self.lineEditYbinning = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditYbinning.sizePolicy().hasHeightForWidth())
        self.lineEditYbinning.setSizePolicy(sizePolicy)
        self.lineEditYbinning.setObjectName("lineEditYbinning")
        self.gridLayout.addWidget(self.lineEditYbinning, 8, 1, 1, 1)
        self.labelScaleUnit = QtWidgets.QLabel(self.groupBox)
        self.labelScaleUnit.setObjectName("labelScaleUnit")
        self.gridLayout.addWidget(self.labelScaleUnit, 8, 2, 1, 1)
        self.lineEditScaleUnit = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditScaleUnit.sizePolicy().hasHeightForWidth())
        self.lineEditScaleUnit.setSizePolicy(sizePolicy)
        self.lineEditScaleUnit.setObjectName("lineEditScaleUnit")
        self.gridLayout.addWidget(self.lineEditScaleUnit, 8, 3, 1, 1)
        self.labelSiteLong = QtWidgets.QLabel(self.groupBox)
        self.labelSiteLong.setObjectName("labelSiteLong")
        self.gridLayout.addWidget(self.labelSiteLong, 9, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEditSiteLong = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSiteLong.sizePolicy().hasHeightForWidth())
        self.lineEditSiteLong.setSizePolicy(sizePolicy)
        self.lineEditSiteLong.setMinimumSize(QtCore.QSize(5, 0))
        self.lineEditSiteLong.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditSiteLong.setObjectName("lineEditSiteLong")
        self.horizontalLayout.addWidget(self.lineEditSiteLong)
        self.lineEditSiteLongF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditSiteLongF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSiteLongF.sizePolicy().hasHeightForWidth())
        self.lineEditSiteLongF.setSizePolicy(sizePolicy)
        self.lineEditSiteLongF.setObjectName("lineEditSiteLongF")
        self.horizontalLayout.addWidget(self.lineEditSiteLongF)
        self.gridLayout.addLayout(self.horizontalLayout, 9, 1, 1, 1)
        self.labelDataUnit = QtWidgets.QLabel(self.groupBox)
        self.labelDataUnit.setObjectName("labelDataUnit")
        self.gridLayout.addWidget(self.labelDataUnit, 9, 2, 1, 1)
        self.lineEditDataUnit = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditDataUnit.sizePolicy().hasHeightForWidth())
        self.lineEditDataUnit.setSizePolicy(sizePolicy)
        self.lineEditDataUnit.setObjectName("lineEditDataUnit")
        self.gridLayout.addWidget(self.lineEditDataUnit, 9, 3, 1, 1)
        self.labelSiteLat = QtWidgets.QLabel(self.groupBox)
        self.labelSiteLat.setObjectName("labelSiteLat")
        self.gridLayout.addWidget(self.labelSiteLat, 10, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lineEditSiteLat = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSiteLat.sizePolicy().hasHeightForWidth())
        self.lineEditSiteLat.setSizePolicy(sizePolicy)
        self.lineEditSiteLat.setMinimumSize(QtCore.QSize(5, 0))
        self.lineEditSiteLat.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditSiteLat.setObjectName("lineEditSiteLat")
        self.horizontalLayout_2.addWidget(self.lineEditSiteLat)
        self.lineEditSiteLatF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditSiteLatF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSiteLatF.sizePolicy().hasHeightForWidth())
        self.lineEditSiteLatF.setSizePolicy(sizePolicy)
        self.lineEditSiteLatF.setObjectName("lineEditSiteLatF")
        self.horizontalLayout_2.addWidget(self.lineEditSiteLatF)
        self.gridLayout.addLayout(self.horizontalLayout_2, 10, 1, 1, 1)
        self.labelCsvFile = QtWidgets.QLabel(self.groupBox)
        self.labelCsvFile.setObjectName("labelCsvFile")
        self.gridLayout.addWidget(self.labelCsvFile, 10, 2, 1, 1)
        self.lineEditCsvFile = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditCsvFile.sizePolicy().hasHeightForWidth())
        self.lineEditCsvFile.setSizePolicy(sizePolicy)
        self.lineEditCsvFile.setObjectName("lineEditCsvFile")
        self.gridLayout.addWidget(self.lineEditCsvFile, 10, 3, 1, 1)
        self.labelRa = QtWidgets.QLabel(self.groupBox)
        self.labelRa.setObjectName("labelRa")
        self.gridLayout.addWidget(self.labelRa, 11, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lineEditRa = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditRa.sizePolicy().hasHeightForWidth())
        self.lineEditRa.setSizePolicy(sizePolicy)
        self.lineEditRa.setMinimumSize(QtCore.QSize(10, 0))
        self.lineEditRa.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditRa.setObjectName("lineEditRa")
        self.horizontalLayout_3.addWidget(self.lineEditRa)
        self.lineEditRaF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditRaF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditRaF.sizePolicy().hasHeightForWidth())
        self.lineEditRaF.setSizePolicy(sizePolicy)
        self.lineEditRaF.setObjectName("lineEditRaF")
        self.horizontalLayout_3.addWidget(self.lineEditRaF)
        self.gridLayout.addLayout(self.horizontalLayout_3, 11, 1, 1, 1)
        self.labelFwhm = QtWidgets.QLabel(self.groupBox)
        self.labelFwhm.setObjectName("labelFwhm")
        self.gridLayout.addWidget(self.labelFwhm, 11, 2, 1, 1)
        self.lineEditFwhm = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditFwhm.sizePolicy().hasHeightForWidth())
        self.lineEditFwhm.setSizePolicy(sizePolicy)
        self.lineEditFwhm.setObjectName("lineEditFwhm")
        self.gridLayout.addWidget(self.lineEditFwhm, 11, 3, 1, 1)
        self.labelDec = QtWidgets.QLabel(self.groupBox)
        self.labelDec.setObjectName("labelDec")
        self.gridLayout.addWidget(self.labelDec, 12, 0, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lineEditDec = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditDec.sizePolicy().hasHeightForWidth())
        self.lineEditDec.setSizePolicy(sizePolicy)
        self.lineEditDec.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditDec.setObjectName("lineEditDec")
        self.horizontalLayout_4.addWidget(self.lineEditDec)
        self.lineEditDecF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditDecF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditDecF.sizePolicy().hasHeightForWidth())
        self.lineEditDecF.setSizePolicy(sizePolicy)
        self.lineEditDecF.setObjectName("lineEditDecF")
        self.horizontalLayout_4.addWidget(self.lineEditDecF)
        self.gridLayout.addLayout(self.horizontalLayout_4, 12, 1, 1, 1)
        self.labelEccentricity = QtWidgets.QLabel(self.groupBox)
        self.labelEccentricity.setObjectName("labelEccentricity")
        self.gridLayout.addWidget(self.labelEccentricity, 12, 2, 1, 1)
        self.lineEditEccentricity = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditEccentricity.sizePolicy().hasHeightForWidth())
        self.lineEditEccentricity.setSizePolicy(sizePolicy)
        self.lineEditEccentricity.setObjectName("lineEditEccentricity")
        self.gridLayout.addWidget(self.lineEditEccentricity, 12, 3, 1, 1)
        self.labelAlt = QtWidgets.QLabel(self.groupBox)
        self.labelAlt.setObjectName("labelAlt")
        self.gridLayout.addWidget(self.labelAlt, 13, 0, 1, 1)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.lineEditAlt = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAlt.sizePolicy().hasHeightForWidth())
        self.lineEditAlt.setSizePolicy(sizePolicy)
        self.lineEditAlt.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditAlt.setObjectName("lineEditAlt")
        self.horizontalLayout_5.addWidget(self.lineEditAlt)
        self.lineEditAltF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditAltF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAltF.sizePolicy().hasHeightForWidth())
        self.lineEditAltF.setSizePolicy(sizePolicy)
        self.lineEditAltF.setObjectName("lineEditAltF")
        self.horizontalLayout_5.addWidget(self.lineEditAltF)
        self.gridLayout.addLayout(self.horizontalLayout_5, 13, 1, 1, 1)
        self.labelSnrWeight = QtWidgets.QLabel(self.groupBox)
        self.labelSnrWeight.setObjectName("labelSnrWeight")
        self.gridLayout.addWidget(self.labelSnrWeight, 13, 2, 1, 1)
        self.lineEditSnrWeight = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSnrWeight.sizePolicy().hasHeightForWidth())
        self.lineEditSnrWeight.setSizePolicy(sizePolicy)
        self.lineEditSnrWeight.setObjectName("lineEditSnrWeight")
        self.gridLayout.addWidget(self.lineEditSnrWeight, 13, 3, 1, 1)
        self.labelAz = QtWidgets.QLabel(self.groupBox)
        self.labelAz.setObjectName("labelAz")
        self.gridLayout.addWidget(self.labelAz, 14, 0, 1, 1)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.lineEditAz = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAz.sizePolicy().hasHeightForWidth())
        self.lineEditAz.setSizePolicy(sizePolicy)
        self.lineEditAz.setMaximumSize(QtCore.QSize(80, 16777215))
        self.lineEditAz.setObjectName("lineEditAz")
        self.horizontalLayout_6.addWidget(self.lineEditAz)
        self.lineEditAzF = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditAzF.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditAzF.sizePolicy().hasHeightForWidth())
        self.lineEditAzF.setSizePolicy(sizePolicy)
        self.lineEditAzF.setObjectName("lineEditAzF")
        self.horizontalLayout_6.addWidget(self.lineEditAzF)
        self.gridLayout.addLayout(self.horizontalLayout_6, 14, 1, 1, 1)
        self.labelNoise = QtWidgets.QLabel(self.groupBox)
        self.labelNoise.setObjectName("labelNoise")
        self.gridLayout.addWidget(self.labelNoise, 14, 2, 1, 1)
        self.lineEditNoise = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(60)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditNoise.sizePolicy().hasHeightForWidth())
        self.lineEditNoise.setSizePolicy(sizePolicy)
        self.lineEditNoise.setObjectName("lineEditNoise")
        self.gridLayout.addWidget(self.lineEditNoise, 14, 3, 1, 1)
        self.lineEditFile = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditFile.setObjectName("lineEditFile")
        self.gridLayout.addWidget(self.lineEditFile, 0, 1, 1, 3)
        self.lineEditHash = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditHash.setObjectName("lineEditHash")
        self.gridLayout.addWidget(self.lineEditHash, 1, 1, 1, 3)
        self.verticalLayout.addWidget(self.groupBox)
        self.verticalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.groupBox.setTitle(_translate("Dialog", "Image Details"))
        self.labelFile.setText(_translate("Dialog", "File Name"))
        self.labelHash.setText(_translate("Dialog", "File Hash"))
        self.labelFileTarget.setText(_translate("Dialog", "Target"))
        self.labelFileDate.setText(_translate("Dialog", "Obs Date"))
        self.labelFrame.setText(_translate("Dialog", "Frame"))
        self.labelGain.setText(_translate("Dialog", "Gain"))
        self.labelFilter.setText(_translate("Dialog", "Filter"))
        self.labelFileOffset.setText(_translate("Dialog", "Offset"))
        self.labelExposure.setText(_translate("Dialog", "Exposure"))
        self.labelSubframeScale.setText(_translate("Dialog", "Scale"))
        self.labelTemp.setText(_translate("Dialog", "Camera Temp"))
        self.labelCameraGain.setText(_translate("Dialog", "Camera Gain"))
        self.labelXBinning.setText(_translate("Dialog", "X Binning"))
        self.labelCameraResolution.setText(_translate("Dialog", "Camera Res"))
        self.labelYbinning.setText(_translate("Dialog", "Y Binning"))
        self.labelScaleUnit.setText(_translate("Dialog", "Scale Unit"))
        self.labelSiteLong.setText(_translate("Dialog", "Site Longitude"))
        self.labelDataUnit.setText(_translate("Dialog", "Data Unit"))
        self.labelSiteLat.setText(_translate("Dialog", "Site Latitude"))
        self.labelCsvFile.setText(_translate("Dialog", "CSV File"))
        self.labelRa.setText(_translate("Dialog", "RA"))
        self.labelFwhm.setText(_translate("Dialog", "FWHM"))
        self.labelDec.setText(_translate("Dialog", "DEC"))
        self.labelEccentricity.setText(_translate("Dialog", "Eccentricity"))
        self.labelAlt.setText(_translate("Dialog", "ALT"))
        self.labelSnrWeight.setText(_translate("Dialog", "SNR Weight"))
        self.labelAz.setText(_translate("Dialog", "AZ"))
        self.labelNoise.setText(_translate("Dialog", "Noise"))
